Package io.github.cdimascio.dotenv
Interface Dotenv
public interface Dotenv
Creates and configures a new dotenv instance
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static classDotenv.FilterA dotenv entry filter -
Method Summary
Modifier and Type Method Description static DotenvBuilderconfigure()Configures a newDotenvinstancejava.util.Set<DotenvEntry>entries()Returns the set of environment variables with valuesjava.util.Set<DotenvEntry>entries(Dotenv.Filter filter)Returns the set ofDotenv.Filters matching the the filterjava.lang.Stringget(java.lang.String key)Retrieves the value of the environment variable specified by keyjava.lang.Stringget(java.lang.String key, java.lang.String defaultValue)Retrieves the value of the environment variable specified by key.static Dotenvload()Creates and loads aDotenvinstance with default options
-
Method Details
-
configure
Configures a newDotenvinstance- Returns:
- a new
Dotenvinstance
-
load
Creates and loads aDotenvinstance with default options- Returns:
- a new
Dotenvinstance
-
entries
java.util.Set<DotenvEntry> entries()Returns the set of environment variables with values- Returns:
- the set of
DotenvEntrys for all environment variables
-
entries
Returns the set ofDotenv.Filters matching the the filter- Parameters:
filter- the filter e.g.Dotenv.Filter- Returns:
- the set of
DotenvEntrys for environment variables matching theDotenv.Filter
-
get
java.lang.String get(java.lang.String key)Retrieves the value of the environment variable specified by key- Parameters:
key- the environment variable- Returns:
- the value of the environment variable
-
get
java.lang.String get(java.lang.String key, java.lang.String defaultValue)Retrieves the value of the environment variable specified by key. If the environment variable specified by key does not exist, then the defaut value is returned- Parameters:
key- the environment variabledefaultValue- the default value to return- Returns:
- the value of the environment variable or default value
-